declare type ValidateMessage = string | (() => string);
export interface ValidateMessages {
    default?: ValidateMessage;
    required?: ValidateMessage;
    enum?: ValidateMessage;
    whitespace?: ValidateMessage;
    date?: {
        format?: ValidateMessage;
        parse?: ValidateMessage;
        invalid?: ValidateMessage;
    };
    types?: {
        string?: ValidateMessage;
        method?: ValidateMessage;
        array?: ValidateMessage;
        object?: ValidateMessage;
        number?: ValidateMessage;
        date?: ValidateMessage;
        boolean?: ValidateMessage;
        integer?: ValidateMessage;
        float?: ValidateMessage;
        regexp?: ValidateMessage;
        email?: ValidateMessage;
        url?: ValidateMessage;
        hex?: ValidateMessage;
    };
    string?: {
        len?: ValidateMessage;
        min?: ValidateMessage;
        max?: ValidateMessage;
        range?: ValidateMessage;
    };
    number?: {
        len?: ValidateMessage;
        min?: ValidateMessage;
        max?: ValidateMessage;
        range?: ValidateMessage;
    };
    array?: {
        len?: ValidateMessage;
        min?: ValidateMessage;
        max?: ValidateMessage;
        range?: ValidateMessage;
    };
    pattern?: {
        mismatch?: ValidateMessage;
    };
}
export interface Props {
    [key: string]: any;
}
export interface validateOptions {
    validateFirst?: boolean;
    validateMessages?: ValidateMessages;
    trigger?: 'change' | 'blur' | string | string[];
}
export interface validateInfo {
    autoLink?: boolean;
    required?: boolean;
    validateStatus?: 'validating' | 'error' | 'success' | null;
    help?: string;
}
export interface validateInfos {
    [key: string]: validateInfo;
}
declare function useForm(modelRef: Props, rulesRef?: Props, options?: {
    immediate?: boolean;
    deep?: boolean;
    validateOnRuleChange?: boolean;
}): {
    modelRef: Props;
    rulesRef: Props;
    initialModel: Props;
    validateInfos: validateInfos;
    resetFields: () => void;
    validate: (names?: string | string[], option?: validateOptions) => Promise<any>;
    validateField: (name?: string, value?: any, rules?: [Record<string, unknown>], option?: validateOptions) => Promise<any>;
    mergeValidateInfo: (...items: validateInfo[]) => validateInfo;
};
export default useForm;
