"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _runtimeDom = require("@vue/runtime-dom");

var _cloneDeep = _interopRequireDefault(require("lodash-es/cloneDeep"));

var _intersection = _interopRequireDefault(require("lodash-es/intersection"));

var _isEqual = _interopRequireDefault(require("lodash-es/isEqual"));

var _validateUtil = require("ant-design-vue/es/form/utils/validateUtil");

var _messages = require("ant-design-vue/es/form/utils/messages");

var _asyncUtil = require("ant-design-vue/es/form/utils/asyncUtil");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function isRequired(rules) {
  var isRequired = false;

  if (rules && rules.length) {
    rules.every(function (rule) {
      if (rule.required) {
        isRequired = true;
        return false;
      }

      return true;
    });
  }

  return isRequired;
}

function toArray(value) {
  if (value === undefined || value === null) {
    return [];
  }

  return Array.isArray(value) ? value : [value];
}

function useForm(modelRef, rulesRef, options) {
  var initialModel = (0, _cloneDeep["default"])(modelRef);
  var validateInfos = {};
  Object.keys(initialModel).forEach(function (key) {
    validateInfos[key] = {
      autoLink: false,
      required: isRequired(rulesRef[key])
    };
  });
  validateInfos = (0, _runtimeDom.reactive)(validateInfos);

  var resetFields = function resetFields() {
    _extends(modelRef, initialModel);

    (0, _runtimeDom.nextTick)(function () {
      Object.keys(validateInfos).forEach(function (key) {
        validateInfos[key] = {
          autoLink: false,
          required: isRequired(rulesRef[key])
        };
      });
    });
  };

  var filterRules = function filterRules() {
    var rules = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var trigger = arguments.length > 1 ? arguments[1] : undefined;

    if (!trigger.length) {
      return rules;
    } else {
      return rules.filter(function (rule) {
        var triggerList = toArray(rule.trigger || 'change');
        return (0, _intersection["default"])(triggerList, trigger).length;
      });
    }
  };

  var lastValidatePromise = null;

  var validateFields = function validateFields(names, option) {
    var promiseList = [];
    var values = {};
    names.forEach(function (name) {
      var value = modelRef[name];
      values[name] = value;
      var rules = filterRules(rulesRef[name], toArray(option && option.trigger));

      if (rules.length) {
        promiseList.push(validateField(name, value, rules, option || {}).then(function () {
          return {
            name: name,
            errors: []
          };
        })["catch"](function (errors) {
          return Promise.reject({
            name: name,
            errors: errors
          });
        }));
      }
    });
    var summaryPromise = (0, _asyncUtil.allPromiseFinish)(promiseList);
    lastValidatePromise = summaryPromise;
    var returnPromise = summaryPromise.then(function () {
      if (lastValidatePromise === summaryPromise) {
        return Promise.resolve(values);
      }

      return Promise.reject([]);
    })["catch"](function (results) {
      var errorList = results.filter(function (result) {
        return result && result.errors.length;
      });
      return Promise.reject({
        values: values,
        errorFields: errorList,
        outOfDate: lastValidatePromise !== summaryPromise
      });
    }); // Do not throw in console

    returnPromise["catch"](function (e) {
      return e;
    });
    return returnPromise;
  };

  var validateField = function validateField(name, value, rules, option) {
    var promise = (0, _validateUtil.validateRules)([name], value, rules, _objectSpread({
      validateMessages: _messages.defaultValidateMessages
    }, option), !!option.validateFirst);
    validateInfos[name].validateStatus = 'validating';
    promise["catch"](function (e) {
      return e;
    }).then(function () {
      var errors = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

      if (validateInfos[name].validateStatus === 'validating') {
        validateInfos[name].validateStatus = errors.length ? 'error' : 'success';
        validateInfos[name].help = errors[0];
      }
    });
    return promise;
  };

  var validate = function validate(names, option) {
    var keys = [];

    if (!names) {
      keys = Object.keys(modelRef);
    } else if (Array.isArray(names)) {
      keys = names;
    } else {
      keys = [names];
    }

    return validateFields(keys, option)["catch"](function (e) {
      return e;
    });
  };

  var mergeValidateInfo = function mergeValidateInfo() {
    var info = {
      autoLink: false
    };
    var help = [];

    for (var i = 0; i < arguments.length; i++) {
      var arg = i < 0 || arguments.length <= i ? undefined : arguments[i];

      if (arg.validateStatus === 'error') {
        info.validateStatus = 'error';
        arg.help && help.push(arg.help);
      }

      info.required = info.required || arg.required;
    }

    info.help = help.join('\n');
    return info;
  };

  var oldModel = initialModel;
  (0, _runtimeDom.watch)(modelRef, function (model) {
    var names = [];
    Object.keys(model).forEach(function (key) {
      if (!(0, _isEqual["default"])(model[key], oldModel[key])) {
        names.push(key);
      }
    });
    validate(names, {
      trigger: 'change'
    });
    oldModel = (0, _cloneDeep["default"])(model);
  }, {
    immediate: options && !!options.immediate,
    deep: true
  });
  (0, _runtimeDom.watch)(rulesRef, function () {
    if (options && options.validateOnRuleChange) {
      validate();
    }
  }, {
    deep: true
  });
  return {
    modelRef: modelRef,
    rulesRef: rulesRef,
    initialModel: initialModel,
    validateInfos: validateInfos,
    resetFields: resetFields,
    validate: validate,
    validateField: validateField,
    mergeValidateInfo: mergeValidateInfo
  };
}

var _default = useForm;
exports["default"] = _default;